@@ -8,7 +8,7 @@ use base qw ( Pipeline::Store );
 
 use Class::ISA;
 
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 sub set {
   my $self = shift;
@@ -40,7 +40,7 @@ sub get {
 1;
 
 
-=head1 
+=head1 NAME
 
 Pipeline::Store::ISA - inheritance-based store for pipelines
 
@@ -80,6 +80,10 @@ returns undef instead.
 
 =back
 
+=head1 SEE ALSO
+
+C<Pipeline>, C<Pipeline::Store>, C<Pipeline::Store::Simple>
+
 =head1 AUTHOR
 
 James A. Duncan <jduncan@fotango.com>
