@@ -6,11 +6,12 @@ use warnings::register;
 use Pipeline::Store;
 use base qw ( Pipeline::Store );
 
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 sub set {
   my $self = shift;
   my $thing = shift;
+  $self->emit("storing " . ref($thing));
   $self->store->{ ref( $thing ) } = $thing;
   return $self;
 }
@@ -19,6 +20,8 @@ sub get {
   my $self = shift;
   my $this = shift;
 
+  $self->emit("fetching $this");
+
   ## is something requesting a copy of 
   ## the store?
   if ($this eq ref($self)) {
@@ -32,7 +35,7 @@ sub get {
 1;
 
 
-=head1 
+=head1 NAME
 
 Pipeline::Store::Simple - simple store for pipelines
 
@@ -70,6 +73,10 @@ returns undef instead.
 
 =back
 
+=head1 SEE ALSO
+
+C<Pipeline>, C<Pipeline::Store>, C<Pipeline::Store::ISA>
+
 =head1 AUTHOR
 
 James A. Duncan <jduncan@fotango.com>
